﻿//*****************************************************************************
// Description     : Class to get command addresses for controlling device
// Target Device   : APN504X
// Target Platform : Windows, .NET Framework, C#
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
using System.Collections.Generic;

namespace APN504X_sample
{
	public class Command
	{
		private static Dictionary<string, uint> dic = new Dictionary<string, uint>() {
			//******************* command address  ********************
			// command
			{"COMMAND_MOD", 0xb4000010},	// measurement mode
			{"COMMAND_AQS", 0xb4000014},	// start/stop
			{"COMMAND_MTM", 0xb4000016},	// measurement time
			{"COMMAND_CLR", 0xb4000040},	// clear data
			{"COMMAND_RQH", 0xb400004a},	// request histogram
			{"COMMAND_DAC", 0xb400007a},	// DAC monitor
	
			{"COMMAND_ACG", 0xb4000200},	// analog coarse gain
			{"COMMAND_ADG", 0xb4000202},	// ADC gain
			{"COMMAND_SFR", 0xb4000208},	// slow filter rise time
			{"COMMAND_SFP", 0xb400020a},	// slow filter peaking time
			{"COMMAND_FPZ", 0xb400020c},	// fast filter pole zero
			{"COMMAND_SPZ", 0xb400020e},	// slow filter pole zero
			{"COMMAND_FTH", 0xb4000210},	// fast trigger threshold
			{"COMMAND_STH", 0xb4000216},	// slow filter threshold
			{"COMMAND_POL", 0xb400021a},	// polarity
			{"COMMAND_RFL", 0xb4000238},	// filter reset
			{"COMMAND_DCG", 0xb400023a},	// digital coarse gain
			{"COMMAND_DFG", 0xb400023c},	// digital fine gain
	
			{"COMMAND_FGD", 0xb4000258},	// analog fine gain
			{"COMMAND_PZD", 0xb4000256},	// analog polezero

			// status
			{"STATUS_RTM", 0xb400001c},		// real time
			{"STATUS_ICR", 0xb400022c},		// input count rate(cps)
			{"STATUS_TCR", 0xb4000230},		// throughput count rate(cps)
	
			//******************* parameter ********************
			// measurement mode
			{"PARAM_MOD_HIST",	0},	// histogram
			{"PARAM_MOD_WAVE",	1},	// wave
	
			// measurement start/stop
			{"PARAM_AQS_STOP",	0},	// stop
			{"PARAM_AQS_START",	1},	// start
	
			// DAC monitor
			{"PARAM_DAC_CH1_PRE",	0},	// CH1 pre amp
			{"PARAM_DAC_CH1_FAST",	1},	// CH1 fast
			{"PARAM_DAC_CH1_SLOW",	2},	// CH1 slow
			{"PARAM_DAC_CH1_CFD",	3},	// CH1 CFD
	
			// analog coarse gain
			{"PARAM_ACG_x5",	1},	// x5
			{"PARAM_ACG_x10",	2},	// x10
			{"PARAM_ACG_x20",	3},	// x20
	
			// ADC gain
			{"PARAM_ADG_4096",	1},	// 4096
			{"PARAM_ADG_2048",	2},	// 2048
			{"PARAM_ADG_1024",	3},	// 1024
			{"PARAM_ADG_512",	4},	//  512
			{"PARAM_ADG_256",	5},	//  256
	
			// polarity
			{"PARAM_POL_POS",	0},	// positive
			{"PARAM_POL_NEG",	1},	// negative
	
			// digital coarse gain
			{"PARAM_DCG_x1",	0},	// x1
			{"PARAM_DCG_x2",	1},	// x2
			{"PARAM_DCG_x4",	2},	// x4
			{"PARAM_DCG_x8",	3},	// x8
			{"PARAM_DCG_x16",	4},	// x16
			{"PARAM_DCG_x32",	5},	// x32
			{"PARAM_DCG_x64",	6},	// x64
			{"PARAM_DCG_x128",	7}	// x128
		};

		public uint GetVal(string key)
		{
			return( dic[key] );
		}

        public uint GetVal(string key, int chnumber)
        {
            uint address = GetVal(key);

            if(chnumber > 0)
            {
                address += (uint)((chnumber - 1) * Device.OFFSETADDR_CH);
            }

            return address;
        }
    }
}
